/***********************************************************************/
/*                                                                     */
/*                            Pio (Fortran)                            */
/*                                                                     */
/*                    Polyglot Input/Output Library                    */
/*                                                                     */
/*               EPI Pomdapi, INRIA Paris - Rocquencourt               */
/*                                                                     */
/*  Copyright 2005-2014 INRIA.                                         */
/*  Institut National de Recherche en Informatique et en Automatique.  */
/*  All rights reserved. This file is distributed only by permission.  */
/*                                                                     */
/*  Francois Clement <Francois.Clement@inria.fr>                       */
/*  Pierre Weis <Pierre.Weis@inria.fr>                                 */
/*  Hend Ben Ameur <hbenameur@yahoo.ca>                                */
/*                                                                     */
/***********************************************************************/

/* $Id: pio_error_codes.h,v 1.9 2014/01/10 19:22:10 fclement Exp $ */

/*
 * Fortran PIO error codes (in the range 192-255).
 */

#ifndef _PIO_ERROR_CODES_H_
#define _PIO_ERROR_CODES_H_

/* Error codes related to external aggressions (in the range 160-163). */
#define PIO_READ_ERROR 160
#define PIO_WRITE_ERROR 161

/* Error codes related to the Fortran implementation of the PIO library
   (in the range 164-195). */
#define PIO_BUFFER_OVERFLOW_ERROR 164
#define PIO_FLUSH_ERROR 165
#define PIO_INCOHERENT_STRING_LENGTH_ERROR 166
#define PIO_IDENT_TOO_LONG_ERROR 167
#define PIO_INVALID_MEMORY_MAPPING_ACCESS_ERROR 168
#define PIO_INVARIANT_ERROR 169
#define PIO_INTERNAL_ERROR 170
#define PIO_LENGTH_TOO_LONG_ERROR 171
#define PIO_MEMORY_ACCESS_ERROR 172
#define PIO_MEMORY_MAPPING_OVERFLOW_ERROR 173
#define PIO_NOT_YET_IMPLEMENTED_ERROR 174
#define PIO_TOO_LONG_STRING_VALUE_ERROR 175
#define PIO_TOO_MANY_ARRAY_DIMENSIONS_ERROR 176
#define PIO_TOO_MANY_VALUES_ERROR 177
#define PIO_TOO_SHORT_LIST_ERROR 178
#define PIO_UNBOUND_LAYOUT_KIND_ERROR 179
#define PIO_UNSET_VALUE_DESCRIPTOR_ADDRESS_ERROR 180
#define PIO_WRONG_COMMUNICATION_TYPE_ERROR 181
#define PIO_WRONG_FLOAT_COMPOUND_SIZE_ERROR 182
#define PIO_WRONG_INT_COMPOUND_SIZE_ERROR 183
#define PIO_WRONG_MEMORY_CLEAN_ERROR 184
#define PIO_WRONG_MEMORY_MAPPING_CLEAN_ERROR 185
#define PIO_WRONG_NUMBER_OF_VALUES_ERROR 186
#define PIO_TOO_LARGE_SIZE_ERROR 187

/* Errors related either to the Fortran implementation of the PIO library
   or to the contents of the received communication (in the range 196-199). */
#define PIO_ASSERTION_FAILURE_ERROR 196

/* Error codes related to the contents of the received communication
   (in the range 200-223). */
#define PIO_CHAR_NOT_FOUND_ERROR 200
#define PIO_CHAR_SYNTAX_ERROR 201
#define PIO_END_OF_FILE_ERROR 202
#define PIO_HETEROGENEOUS_TUPLE_TYPE_ERROR 203
#define PIO_INCOHERENT_ARRAY_MARKERS_ERROR 204
#define PIO_LENGTH_TOO_SHORT_ERROR 205
#define PIO_LINE_SYNTAX_ERROR 206
#define PIO_MALFORMED_ESCAPED_CHAR_ERROR 207
#define PIO_UNKNOWN_SERVICE_NAME_ERROR 208
#define PIO_UNKNOWN_TYPED_VALUE_TYPE_ERROR 209
#define PIO_WRONG_COMMUNICATION_FORMAT_ERROR 210
#define PIO_WRONG_FLOAT_SIZE_ERROR 211
#define PIO_WRONG_STRING_LENGTH_ERROR 212
#define PIO_WRONG_TYPED_VALUE_BINARY_TYPE_ERROR 213
#define PIO_WRONG_TYPED_VALUE_TYPE_ERROR 214
#define PIO_WRONG_DIMENSION_ERROR 215
#define PIO_WRONG_SIZE_ERROR 216
#define PIO_EMPTY_TOKEN_ERROR 217

#endif
