(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2013-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: identity_model_scalar.ml,v 1.1 2014-02-19 15:01:02 fclement Exp $ *)

open Gen_identity_model;;

(* Single stuff. *)

let get_dimension () = Nat._1_;;

let single_of_color c =
  let (r, g, b) = (Colors.r_of c, Colors.g_of c, Colors.b_of c) in
  if r = g && g = b then r else
  i_failwith "single_of_color" "color is not grayscale"
;;

let single_of_array = function
  | [| x0; |] -> x0
  | _ -> i_invalid_arg "single_of_array" "length of array is not 1"
;;

(* Grayscale image stuff. *)

let of_color c = float_of_int (single_of_color c);;

let to_color t =
  let r = int_of_float t in
  Colors.color_of_rgb r r r
;;

let data_of_image img =
  let im = Umatrix.map of_color img in
  let dms = im in
  Umatrix.of_array_array (Array.map Umatrix.to_array [| dms; |])
;;

let image_of_fine_parameter (ni, nj) pm =
  let rm =
    single_of_array
      (Array.map
         (Uarray_ng.matrix_of_array ni nj)
         (Umatrix.to_array_array pm)) in
  Umatrix.map to_color rm
;;
