(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2013-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: umatrix_hashtbl.ml,v 1.6 2014-02-10 18:12:49 fclement Exp $*)

(* Matrix hash tables. *)

module Nat = Unatural;;

module Index = Umatrix_index;;
module Gen_hashtbl = Ugen_numbering_hashtbl;;

let mh_qual = Upervasives.qualify "Umatrix_hashtbl";;

let mh_invalid_arg = Upervasives.invalid_arg_qual mh_qual;;

type size = Upervasives.length * Upervasives.length;;
type key = Index.element;;
type value = Index.index;;

type t = (size, key) Gen_hashtbl.t;;

external of_t : t -> (size, key) Ugen_numbering_hashtbl.t = "%identity";;

(* Construction function. *)

let valid_key (ni, nj) (i, j) = i < ni && j < nj;;

let check_key sz (i, j as k) =
  if not (valid_key sz k) then
      mh_invalid_arg ""
        (Printf.sprintf "key (%d, %d) out of bounds"
           (Nat.to_int i)
           (Nat.to_int j))
;;

let valid_value len v = Index.to_natural v < len;;

let check_value len v =
  if not (valid_value len v) then
    mh_invalid_arg ""
      (Printf.sprintf "value %d out of bounds" (Index.to_int v))
;;

let make (ni, nj as sz) =
  let len = Nat.mul ni nj in
  let h (i, j as k) =
    check_key sz k;
    let ii = Nat.add (Nat.mul i nj) j in
    Index.of_natural ii in
  let h_inv v =
    check_value len v;
    let ii = Index.to_natural v in
    (Nat.div ii nj, Nat.rem ii nj) in
  { Gen_hashtbl.length = len; size = sz; h = h; h_inv = h_inv; }
;;

(* Access functions. *)

let length = Gen_hashtbl.length;;

let size = Gen_hashtbl.size;;

let mem mh = valid_key mh.Gen_hashtbl.size;;

let value_of_key = Gen_hashtbl.value_of_key;;

let key_of_value = Gen_hashtbl.key_of_value;;

(* Iterators. *)

let iter f = Gen_hashtbl.iter f;;

let fold_left f = Gen_hashtbl.fold_left f;;
