(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2013-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: display_quantity.ml,v 1.23 2014-02-26 23:33:54 fclement Exp $ *)

module Nat = Unatural;;

module Set = Umatrix_nonempty_set;;
module Mapping = Umatrix_graph;;
module Structural_mapping = Umatrix_structural_mapping;;

module Config = Configuration;;

let dq_print_debug_no_arg = Config.print_debug_no_arg "Display_quantity";;

open Display_types;;
open Zonation;;
open Scalar_spec;;
open Components_spec;;
open Display_window;;

module Make =
  functor (Scal : SCALAR) ->
  functor (Comps : COMPONENTS) ->
struct
  module Dqc = Display_quantity_components.Make (Scal) (Comps);;
  module Bb = Dqc.Bb;;
  module St = Dqc.St;;
  module H = Dqc.H;;
  
  module Dqt = Dqc.Dqt;;
  open Dqt;;
  open Dqc;;
  
  let ppf = Config.get_formatter ();;
  
  (* Display_quantity. *)
  
  let fk_dq =
    {
     print_pixmaps = fake_print_pixmaps;
     alter_pixmaps = fake_alter_pixmaps;
     draw_pixmaps = fake_draw_pixmaps;
    }
  ;;
  
  let mk_dq q gk rgb_dir d_sz =
    let pxms = make_pixmaps q gk d_sz in
    let print_pixmaps = make_print_pixmaps q pxms gk in
    let alter_pixmaps = make_alter_pixmaps q pxms gk in
    let lls = make_lower_left_corners q gk rgb_dir d_sz margin in
    let draw_pixmaps = make_draw_pixmaps q pxms lls gk in
    {
     print_pixmaps = print_pixmaps;
     alter_pixmaps = alter_pixmaps;
     draw_pixmaps = draw_pixmaps;
    }
  ;;
  
  (* Display_quantities. *)
  
  let fk_dqs = { dq_param = fk_dq; dq_grad = fk_dq; };;
  
  let { Uaref.get = get_display_quantities; set = set_display_quantities; } =
    Uaref.make_aref_unique "display quantities" fk_dqs
  ;;
  
  let make_display_quantities gk rgb_dir d_sz =
    let mk_dq q = mk_dq q in
    {
     dq_param = mk_dq Param gk rgb_dir d_sz;
     dq_grad = mk_dq Grad gk rgb_dir d_sz;
    }
  ;;
  
  let get_dq dqs = function
    | Param -> dqs.dq_param
    | Grad -> dqs.dq_grad
  ;;
  
  (* Setup. *)
  
  let display_quantities_setup gk comps_dir d_sz =
    set_display_quantities (make_display_quantities gk comps_dir d_sz);
  ;;
  
  let setup gk min_w_sz max_w_sz sz =
    window_setup (Comps.get_dim ()) gk min_w_sz max_w_sz sz;
    let { comps_direction = comps_dir;
          display_image_size = d_sz; _; } = get_graphics_elements () in
    display_quantities_setup gk comps_dir d_sz;
  ;;
  
  (* Drawing shortcuts. *)
  
  let get_stc q =
    let cm =
      match q with
      | Param -> Config.get_graphics_parameter_color_mapping ()
      | Grad -> Config.get_graphics_gradient_color_mapping () in
    Upervasives.compose (Colormapping.get_color cm) Scal.to_float
  ;;
  
  let alter_quantity iter q =
    let dqs = get_display_quantities () in
    let { print_pixmaps = prts; alter_pixmaps = alts; _; } = get_dq dqs q in
    let stcs = Comps.make (get_stc q) in
    (fun pps ->
      alter_apply iter stcs pps alts;
      print_apply dq_print_debug_no_arg ppf prts;)
  ;;
  
  let draw_quantity q =
    let dqs = get_display_quantities () in
    let { draw_pixmaps = drws; _; } = get_dq dqs q in
    draw_apply drws;
  ;;
  
  let alter_and_draw_quantity iter q pps =
    alter_quantity iter q pps;
    draw_quantity q;
  ;;
  
  let iter_set = partition_iter
  and iter_upd = partition_iter
  ;;
  
  let set_quantity_and_draw = alter_and_draw_quantity iter_set
  and update_quantity_and_draw = alter_and_draw_quantity iter_upd
  ;;
end
;;
